#!/bin/bash
# Script to run make install with input target and arguments

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

: ${machine:=sw4l}
date=$(date +%Y%m%d%H%M%S)

ATF_BASE_NAME="${PACKAGE_ID}-${machine}-${date}"
ATF_LINK_NAME="${PACKAGE_ID}-${machine}-latest"

outputDir=${buildDir}/zynqmp/release
bootDir=${installDir}/boot

do_buildstep_prepend

log_exec install -d ${bootDir}
log_exec install -Dm 0644 ${outputDir}/bl31/bl31.elf ${bootDir}/bl31.elf
log_exec install -Dm 0644 ${outputDir}/bl31/bl31.elf ${bootDir}/arm-trusted-firmware.elf


# Do deploy
log_exec install -m 0644 ${outputDir}/bl31.bin ${bootDir}/${ATF_BASE_NAME}.bin

# Create symbolic link to latest bin
log_exec ln -nfs "${bootDir}/${ATF_BASE_NAME}.bin" "${bootDir}/${ATF_LINK_NAME}.bin"

# Get the entry point address from the elf.
BL31_BASE_ADDR=$(${READELF} -h ${outputDir}/bl31/bl31.elf | egrep -m 1 -i "entry point.*?0x" | sed -r 's/.*?(0x.*?)/\1/g')

log_exec mkimage -A arm64 -O arm-trusted-firmware -T kernel -C none \
			-a $BL31_BASE_ADDR -e $BL31_BASE_ADDR \
			-d ${outputDir}/bl31.bin ${bootDir}/${ATF_BASE_NAME}.ub
log_exec ln -sf ${ATF_BASE_NAME}.ub ${bootDir}/arm-trusted-firmware.ub
log_exec ln -sf ${ATF_BASE_NAME}.ub ${bootDir}/atf-uboot.ub

do_buildstep_append
